@@ -1,14 +1,11 @@
 package Weed::Environment;
 use Weed::Perl;
 
-our $VERSION = '0.012';
+our $VERSION = '0.009';
 
 use Weed::Math;
-
-use Weed::Package;
-use Weed::Namespace;
-
 use Weed::Universal;
+
 use Weed::Generator;
 use Weed::Message;
 
@@ -16,6 +13,9 @@ use Weed::Array;
 use Weed::Hash;
 use Weed::ArrayHash;
 
+use Weed::Name;
+
+use Weed::ObjectHash;
 use Weed::ParentHash;
 
 use Weed::Values;
@@ -30,11 +30,7 @@ use Weed::FieldTypes;
 
 use Weed::Constants;
 
-use Weed::Name;
 use Weed::BaseNode;
-use Weed::Route;
-
-use Weed::ExecutionContext;
 
 1;
 __END__
