@@ -1,12 +1,9 @@
 package Weed::FieldDefinition;
 
-our $VERSION = '0.013';
+our $VERSION = '0.009';
 
 use Weed 'X3DFieldDefinition : X3DObject { }';
 
-use Want      ();
-use Sub::Name ();
-
 use overload 'eq' => sub {
 	return YES if !defined( $_[0]->getValue ) && !defined( $_[1]->getValue );
 	return NO if defined( $_[0]->getValue ) ^ defined( $_[1]->getValue );
@@ -14,7 +11,7 @@ use overload 'eq' => sub {
 };
 
 sub new {
-	my $this = shift->X3DObject::new;
+	my $this = shift->CREATE;
 	@$this{qw'type in out name value range'} = @_;
 	return $this;
 }
@@ -36,49 +33,15 @@ sub getRange { $_[0]->{range} }
 sub createField {
 	my ( $this, $node ) = @_;
 
-	my $field = $this->getType->X3DObject::new;
+	my $field = $this->getType->new_from_definition($this);
 
 	$field->getParents->add($node);
-	$field->setDefinition($this);
 
-	$field->create;
+	$field->setValue( $this->getValue );
 
 	return $field;
 }
 
-sub createFieldClosure {
-	my $this    = shift;
-	my $name    = $this->getName;
-	my $package = $this->getName;
-
-	return Sub::Name::subname "$package\::$name" => sub  : lvalue {
-		#X3DMessage->Debug( $_[0], caller(0) );
-		my $this = shift;
-
-		#X3DMessage->DirectOutputIsFALSE, return unless $this->{directOutput};
-
-		if ( Want::want('RVALUE') ) {
-			my $field = $this->getField($name);
-			Want::rreturn $field if Want::want 'ARRAY';
-			Want::rreturn $field->getClone->getValue;
-		}
-
-		if ( Want::want('ASSIGN') ) {
-			$this->getField($name)->setValue( Want::want('ASSIGN') );
-			Want::lnoreturn;
-		}
-
-		if ( Want::want('CODE') ) {
-			my $value = $this->getField($name)->getClone->getValue;
-			return $value;
-		}
-
-		return $this->getFields->getField( $name, $this ) if Want::want('REF');
-
-		$this->getFields->getTiedField( $name, $this )    # fr: += ++ ...
-	  }
-}
-
 #	MFNode   [in,out] children       []       [X3DChildNode]
 sub toString {
 	my ($this) = @_;
