@@ -1,20 +1,18 @@
 package Weed::FieldTypes::MFNode;
 
-our $VERSION = '0.012';
+our $VERSION = '0.009';
 
 use Weed 'MFNode : X3DArrayField { [] }';
 
 use Weed::Tie::Value::BaseNodeArray;
 
-sub create {
-	my ($this) = @_;
+sub new_from_definition {
+	my $this = shift->X3DField::new_from_definition(@_);
 
-	$this->{value} = $this->getInitialValue->getClone;
 	$this->{array} = new Weed::Tie::Value::BaseNodeArray $this;
-
 	tie $this->{length}, 'Weed::Tie::ArrayLength', $this->{array};
 
-	return;
+	return $this;
 }
 
 sub toString {
@@ -69,8 +67,6 @@ sub dispose {
 
 sub DESTROY {
 	my $this = shift;
-	#print $this->getName if defined $this;
-	#$this->X3DArrayField::DESTROY;
 	$this->setValue( [] );
 }
 
