@@ -1,16 +1,18 @@
 package Weed::RegularExpressions;
 use Weed::Perl;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009';
 
 use Weed::Symbols;
 
 use base 'Exporter';
 
 our @EXPORT = qw(
+  $_supertype
   $_RestrictedId
   $_colon
   $_colon_test
+  $_week_hash
   $_open_parenthesis
   $_close_parenthesis
   $_FieldDefinition
@@ -81,6 +83,7 @@ our $open_parenthesis    = '\\' . $_open_parenthesis_;
 our $close_parenthesis   = '\\' . $_close_parenthesis_;
 our $colon               = '\\' . $_colon_;
 our $swung_dash          = '\\' . $_swung_dash_;
+our $_supertype          = qr.^(?!Weed::|main).so;
 
 # General
 our $space      = "[\x20\t]";
@@ -123,6 +126,7 @@ our $Id          = "$IdFirstChar$IdRestChars*";
 our $RestrictedIdFirstChar = '[^\x30-\x39\x00-\x23\x27\x2b\x2c\x2d\x2e\x5b\x5c\x5d\x7b\x7d-\x7f()]{1}';
 our $RestrictedId          = "$RestrictedIdFirstChar$IdRestChars*";
 our $_space_break_space    = qr.$space*$break$space*.so;
+our $_week_hash            = qr.\G$whitespace*$swung_dash$open_brace.so;
 our $_in                   = qr.\G$whitespace*$_in_.so;
 our $_out                  = qr.\G$whitespace*$_out_.so;
 
@@ -133,7 +137,7 @@ our $_out                  = qr.\G$whitespace*$_out_.so;
 our $_break      = qr.$break.so;
 our $_header     = qr.\A$header.so;
 our $_comment    = qr.\G$whitespace*$comment.so;
-our $_whitespace = qr.\G$whitespace*.so;
+our $_whitespace = qr.$whitespace+.so;
 
 # concept
 
