@@ -1,19 +1,19 @@
 package Weed::Universal;
 use Weed::Perl;
 
-our $VERSION = '0.013';
+our $VERSION = '0.009';
 
 use Carp ();
 use Hash::NoRef;
 
 #use Weed::Math;
+use Weed::RegularExpressions '$_supertype';
 use Weed::Package;
 
 use overload
   'bool' => sub { YES },
 
-  '0+'  => 'getId',
-  'int' => 'getId',
+  'int' => sub { &getId( $_[0] ) },
 
   '<=>' => sub { $_[2] ? int( $_[1] ) <=> int( $_[0] ) : int( $_[0] ) <=> int( $_[1] ) },    #???
 
@@ -32,19 +32,19 @@ BEGIN {
 	X3DPackage::createType( __PACKAGE__, 'X3DUniversal', 'X3DUniversal { }', 'getId getReferenceCount' );
 }
 
-sub new {
+sub _new {
 	my $packageName = shift->X3DPackage::getName;
 	$packageName->X3DPackage::Scalar("Description")->{new}->( $packageName, @_ );
 }
 
-sub getId { Scalar::Util::refaddr( $_[0] ) }
-
 sub getType { ref $_[0] }
 
-sub getHierarchy { my $i = 0; X3DArray->new( [ grep { X3DMath::even( $i++ ) } @{ X3DPackage::getPath( $_[0] ) } ] ) }
+sub getId { Scalar::Util::refaddr $_[0] }
 
 *getReferenceCount = \&Hash::NoRef::SvREFCNT;
 
+sub getHierarchy { grep /$_supertype/, X3DPackage::getSelfAndSuperpath( $_[0] ) }
+
 *toString = \&overload::StrVal;
 
 1;
